@@ -38,6 +38,35 @@ class CfnCluster(
 
     :cloudformationResource: AWS::DAX::Cluster
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_dax as dax
+        
+        # tags is of type object
+        
+        cfn_cluster = dax.CfnCluster(self, "MyCfnCluster",
+            iam_role_arn="iamRoleArn",
+            node_type="nodeType",
+            replication_factor=123,
+        
+            # the properties below are optional
+            availability_zones=["availabilityZones"],
+            cluster_endpoint_encryption_type="clusterEndpointEncryptionType",
+            cluster_name="clusterName",
+            description="description",
+            notification_topic_arn="notificationTopicArn",
+            parameter_group_name="parameterGroupName",
+            preferred_maintenance_window="preferredMaintenanceWindow",
+            security_group_ids=["securityGroupIds"],
+            sse_specification=dax.CfnCluster.SSESpecificationProperty(
+                sse_enabled=False
+            ),
+            subnet_group_name="subnetGroupName",
+            tags=tags
+        )
     '''
 
     def __init__(
@@ -45,16 +74,16 @@ class CfnCluster(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        iam_role_arn: builtins.str,
-        node_type: builtins.str,
-        replication_factor: jsii.Number,
         availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
         cluster_endpoint_encryption_type: typing.Optional[builtins.str] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
+        iam_role_arn: builtins.str,
+        node_type: builtins.str,
         notification_topic_arn: typing.Optional[builtins.str] = None,
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        replication_factor: jsii.Number,
         security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, "CfnCluster.SSESpecificationProperty"]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
@@ -64,32 +93,32 @@ class CfnCluster(
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
-        :param node_type: ``AWS::DAX::Cluster.NodeType``.
-        :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param availability_zones: ``AWS::DAX::Cluster.AvailabilityZones``.
         :param cluster_endpoint_encryption_type: ``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
         :param cluster_name: ``AWS::DAX::Cluster.ClusterName``.
         :param description: ``AWS::DAX::Cluster.Description``.
+        :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
+        :param node_type: ``AWS::DAX::Cluster.NodeType``.
         :param notification_topic_arn: ``AWS::DAX::Cluster.NotificationTopicARN``.
         :param parameter_group_name: ``AWS::DAX::Cluster.ParameterGroupName``.
         :param preferred_maintenance_window: ``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
+        :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param security_group_ids: ``AWS::DAX::Cluster.SecurityGroupIds``.
         :param sse_specification: ``AWS::DAX::Cluster.SSESpecification``.
         :param subnet_group_name: ``AWS::DAX::Cluster.SubnetGroupName``.
         :param tags: ``AWS::DAX::Cluster.Tags``.
         '''
         props = CfnClusterProps(
-            iam_role_arn=iam_role_arn,
-            node_type=node_type,
-            replication_factor=replication_factor,
             availability_zones=availability_zones,
             cluster_endpoint_encryption_type=cluster_endpoint_encryption_type,
             cluster_name=cluster_name,
             description=description,
+            iam_role_arn=iam_role_arn,
+            node_type=node_type,
             notification_topic_arn=notification_topic_arn,
             parameter_group_name=parameter_group_name,
             preferred_maintenance_window=preferred_maintenance_window,
+            replication_factor=replication_factor,
             security_group_ids=security_group_ids,
             sse_specification=sse_specification,
             subnet_group_name=subnet_group_name,
@@ -116,12 +145,6 @@ class CfnCluster(
         '''
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore[misc]
-    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
-    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        '''The CloudFormation resource type name for this resource class.'''
-        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="attrArn")
     def attr_arn(self) -> builtins.str:
@@ -146,59 +169,6 @@ class CfnCluster(
         '''
         return typing.cast(builtins.str, jsii.get(self, "attrClusterDiscoveryEndpointUrl"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="cfnProperties")
-    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="tags")
-    def tags(self) -> aws_cdk.core.TagManager:
-        '''``AWS::DAX::Cluster.Tags``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
-        '''
-        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="iamRoleArn")
-    def iam_role_arn(self) -> builtins.str:
-        '''``AWS::DAX::Cluster.IAMRoleARN``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "iamRoleArn"))
-
-    @iam_role_arn.setter
-    def iam_role_arn(self, value: builtins.str) -> None:
-        jsii.set(self, "iamRoleArn", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="nodeType")
-    def node_type(self) -> builtins.str:
-        '''``AWS::DAX::Cluster.NodeType``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
-        '''
-        return typing.cast(builtins.str, jsii.get(self, "nodeType"))
-
-    @node_type.setter
-    def node_type(self, value: builtins.str) -> None:
-        jsii.set(self, "nodeType", value)
-
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="replicationFactor")
-    def replication_factor(self) -> jsii.Number:
-        '''``AWS::DAX::Cluster.ReplicationFactor``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
-        '''
-        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))
-
-    @replication_factor.setter
-    def replication_factor(self, value: jsii.Number) -> None:
-        jsii.set(self, "replicationFactor", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="availabilityZones")
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -215,6 +185,17 @@ class CfnCluster(
     ) -> None:
         jsii.set(self, "availabilityZones", value)
 
+    @jsii.python.classproperty # type: ignore[misc]
+    @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
+    def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="cfnProperties")
+    def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="clusterEndpointEncryptionType")
     def cluster_endpoint_encryption_type(self) -> typing.Optional[builtins.str]:
@@ -257,6 +238,32 @@ class CfnCluster(
     def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="iamRoleArn")
+    def iam_role_arn(self) -> builtins.str:
+        '''``AWS::DAX::Cluster.IAMRoleARN``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "iamRoleArn"))
+
+    @iam_role_arn.setter
+    def iam_role_arn(self, value: builtins.str) -> None:
+        jsii.set(self, "iamRoleArn", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="nodeType")
+    def node_type(self) -> builtins.str:
+        '''``AWS::DAX::Cluster.NodeType``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "nodeType"))
+
+    @node_type.setter
+    def node_type(self, value: builtins.str) -> None:
+        jsii.set(self, "nodeType", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="notificationTopicArn")
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
@@ -299,6 +306,19 @@ class CfnCluster(
     ) -> None:
         jsii.set(self, "preferredMaintenanceWindow", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="replicationFactor")
+    def replication_factor(self) -> jsii.Number:
+        '''``AWS::DAX::Cluster.ReplicationFactor``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
+        '''
+        return typing.cast(jsii.Number, jsii.get(self, "replicationFactor"))
+
+    @replication_factor.setter
+    def replication_factor(self, value: jsii.Number) -> None:
+        jsii.set(self, "replicationFactor", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="securityGroupIds")
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
@@ -346,6 +366,15 @@ class CfnCluster(
     def subnet_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> aws_cdk.core.TagManager:
+        '''``AWS::DAX::Cluster.Tags``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-tags
+        '''
+        return typing.cast(aws_cdk.core.TagManager, jsii.get(self, "tags"))
+
     @jsii.data_type(
         jsii_type="@aws-cdk/aws-dax.CfnCluster.SSESpecificationProperty",
         jsii_struct_bases=[],
@@ -361,6 +390,16 @@ class CfnCluster(
             :param sse_enabled: ``CfnCluster.SSESpecificationProperty.SSEEnabled``.
 
             :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dax-cluster-ssespecification.html
+
+            Example::
+
+                # The code below shows an example of how to instantiate this type.
+                # The values are placeholders you should change.
+                import aws_cdk.aws_dax as dax
+                
+                s_sESpecification_property = dax.CfnCluster.SSESpecificationProperty(
+                    sse_enabled=False
+                )
             '''
             self._values: typing.Dict[str, typing.Any] = {}
             if sse_enabled is not None:
@@ -393,16 +432,16 @@ class CfnCluster(
     jsii_type="@aws-cdk/aws-dax.CfnClusterProps",
     jsii_struct_bases=[],
     name_mapping={
-        "iam_role_arn": "iamRoleArn",
-        "node_type": "nodeType",
-        "replication_factor": "replicationFactor",
         "availability_zones": "availabilityZones",
         "cluster_endpoint_encryption_type": "clusterEndpointEncryptionType",
         "cluster_name": "clusterName",
         "description": "description",
+        "iam_role_arn": "iamRoleArn",
+        "node_type": "nodeType",
         "notification_topic_arn": "notificationTopicArn",
         "parameter_group_name": "parameterGroupName",
         "preferred_maintenance_window": "preferredMaintenanceWindow",
+        "replication_factor": "replicationFactor",
         "security_group_ids": "securityGroupIds",
         "sse_specification": "sseSpecification",
         "subnet_group_name": "subnetGroupName",
@@ -413,16 +452,16 @@ class CfnClusterProps:
     def __init__(
         self,
         *,
-        iam_role_arn: builtins.str,
-        node_type: builtins.str,
-        replication_factor: jsii.Number,
         availability_zones: typing.Optional[typing.Sequence[builtins.str]] = None,
         cluster_endpoint_encryption_type: typing.Optional[builtins.str] = None,
         cluster_name: typing.Optional[builtins.str] = None,
         description: typing.Optional[builtins.str] = None,
+        iam_role_arn: builtins.str,
+        node_type: builtins.str,
         notification_topic_arn: typing.Optional[builtins.str] = None,
         parameter_group_name: typing.Optional[builtins.str] = None,
         preferred_maintenance_window: typing.Optional[builtins.str] = None,
+        replication_factor: jsii.Number,
         security_group_ids: typing.Optional[typing.Sequence[builtins.str]] = None,
         sse_specification: typing.Optional[typing.Union[aws_cdk.core.IResolvable, CfnCluster.SSESpecificationProperty]] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
@@ -430,22 +469,51 @@ class CfnClusterProps:
     ) -> None:
         '''Properties for defining a ``AWS::DAX::Cluster``.
 
-        :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
-        :param node_type: ``AWS::DAX::Cluster.NodeType``.
-        :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param availability_zones: ``AWS::DAX::Cluster.AvailabilityZones``.
         :param cluster_endpoint_encryption_type: ``AWS::DAX::Cluster.ClusterEndpointEncryptionType``.
         :param cluster_name: ``AWS::DAX::Cluster.ClusterName``.
         :param description: ``AWS::DAX::Cluster.Description``.
+        :param iam_role_arn: ``AWS::DAX::Cluster.IAMRoleARN``.
+        :param node_type: ``AWS::DAX::Cluster.NodeType``.
         :param notification_topic_arn: ``AWS::DAX::Cluster.NotificationTopicARN``.
         :param parameter_group_name: ``AWS::DAX::Cluster.ParameterGroupName``.
         :param preferred_maintenance_window: ``AWS::DAX::Cluster.PreferredMaintenanceWindow``.
+        :param replication_factor: ``AWS::DAX::Cluster.ReplicationFactor``.
         :param security_group_ids: ``AWS::DAX::Cluster.SecurityGroupIds``.
         :param sse_specification: ``AWS::DAX::Cluster.SSESpecification``.
         :param subnet_group_name: ``AWS::DAX::Cluster.SubnetGroupName``.
         :param tags: ``AWS::DAX::Cluster.Tags``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_dax as dax
+            
+            # tags is of type object
+            
+            cfn_cluster_props = dax.CfnClusterProps(
+                iam_role_arn="iamRoleArn",
+                node_type="nodeType",
+                replication_factor=123,
+            
+                # the properties below are optional
+                availability_zones=["availabilityZones"],
+                cluster_endpoint_encryption_type="clusterEndpointEncryptionType",
+                cluster_name="clusterName",
+                description="description",
+                notification_topic_arn="notificationTopicArn",
+                parameter_group_name="parameterGroupName",
+                preferred_maintenance_window="preferredMaintenanceWindow",
+                security_group_ids=["securityGroupIds"],
+                sse_specification=dax.CfnCluster.SSESpecificationProperty(
+                    sse_enabled=False
+                ),
+                subnet_group_name="subnetGroupName",
+                tags=tags
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "iam_role_arn": iam_role_arn,
@@ -475,36 +543,6 @@ class CfnClusterProps:
         if tags is not None:
             self._values["tags"] = tags
 
-    @builtins.property
-    def iam_role_arn(self) -> builtins.str:
-        '''``AWS::DAX::Cluster.IAMRoleARN``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
-        '''
-        result = self._values.get("iam_role_arn")
-        assert result is not None, "Required property 'iam_role_arn' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def node_type(self) -> builtins.str:
-        '''``AWS::DAX::Cluster.NodeType``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
-        '''
-        result = self._values.get("node_type")
-        assert result is not None, "Required property 'node_type' is missing"
-        return typing.cast(builtins.str, result)
-
-    @builtins.property
-    def replication_factor(self) -> jsii.Number:
-        '''``AWS::DAX::Cluster.ReplicationFactor``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
-        '''
-        result = self._values.get("replication_factor")
-        assert result is not None, "Required property 'replication_factor' is missing"
-        return typing.cast(jsii.Number, result)
-
     @builtins.property
     def availability_zones(self) -> typing.Optional[typing.List[builtins.str]]:
         '''``AWS::DAX::Cluster.AvailabilityZones``.
@@ -541,6 +579,26 @@ class CfnClusterProps:
         result = self._values.get("description")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def iam_role_arn(self) -> builtins.str:
+        '''``AWS::DAX::Cluster.IAMRoleARN``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-iamrolearn
+        '''
+        result = self._values.get("iam_role_arn")
+        assert result is not None, "Required property 'iam_role_arn' is missing"
+        return typing.cast(builtins.str, result)
+
+    @builtins.property
+    def node_type(self) -> builtins.str:
+        '''``AWS::DAX::Cluster.NodeType``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-nodetype
+        '''
+        result = self._values.get("node_type")
+        assert result is not None, "Required property 'node_type' is missing"
+        return typing.cast(builtins.str, result)
+
     @builtins.property
     def notification_topic_arn(self) -> typing.Optional[builtins.str]:
         '''``AWS::DAX::Cluster.NotificationTopicARN``.
@@ -568,6 +626,16 @@ class CfnClusterProps:
         result = self._values.get("preferred_maintenance_window")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def replication_factor(self) -> jsii.Number:
+        '''``AWS::DAX::Cluster.ReplicationFactor``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-cluster.html#cfn-dax-cluster-replicationfactor
+        '''
+        result = self._values.get("replication_factor")
+        assert result is not None, "Required property 'replication_factor' is missing"
+        return typing.cast(jsii.Number, result)
+
     @builtins.property
     def security_group_ids(self) -> typing.Optional[typing.List[builtins.str]]:
         '''``AWS::DAX::Cluster.SecurityGroupIds``.
@@ -628,6 +696,20 @@ class CfnParameterGroup(
 
     :cloudformationResource: AWS::DAX::ParameterGroup
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_dax as dax
+        
+        # parameter_name_values is of type object
+        
+        cfn_parameter_group = dax.CfnParameterGroup(self, "MyCfnParameterGroup",
+            description="description",
+            parameter_group_name="parameterGroupName",
+            parameter_name_values=parameter_name_values
+        )
     '''
 
     def __init__(
@@ -684,19 +766,6 @@ class CfnParameterGroup(
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="parameterNameValues")
-    def parameter_name_values(self) -> typing.Any:
-        '''``AWS::DAX::ParameterGroup.ParameterNameValues``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
-        '''
-        return typing.cast(typing.Any, jsii.get(self, "parameterNameValues"))
-
-    @parameter_name_values.setter
-    def parameter_name_values(self, value: typing.Any) -> None:
-        jsii.set(self, "parameterNameValues", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
@@ -723,6 +792,19 @@ class CfnParameterGroup(
     def parameter_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "parameterGroupName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="parameterNameValues")
+    def parameter_name_values(self) -> typing.Any:
+        '''``AWS::DAX::ParameterGroup.ParameterNameValues``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html#cfn-dax-parametergroup-parameternamevalues
+        '''
+        return typing.cast(typing.Any, jsii.get(self, "parameterNameValues"))
+
+    @parameter_name_values.setter
+    def parameter_name_values(self, value: typing.Any) -> None:
+        jsii.set(self, "parameterNameValues", value)
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-dax.CfnParameterGroupProps",
@@ -748,6 +830,20 @@ class CfnParameterGroupProps:
         :param parameter_name_values: ``AWS::DAX::ParameterGroup.ParameterNameValues``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-parametergroup.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_dax as dax
+            
+            # parameter_name_values is of type object
+            
+            cfn_parameter_group_props = dax.CfnParameterGroupProps(
+                description="description",
+                parameter_group_name="parameterGroupName",
+                parameter_name_values=parameter_name_values
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {}
         if description is not None:
@@ -806,6 +902,20 @@ class CfnSubnetGroup(
 
     :cloudformationResource: AWS::DAX::SubnetGroup
     :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
+
+    Example::
+
+        # The code below shows an example of how to instantiate this type.
+        # The values are placeholders you should change.
+        import aws_cdk.aws_dax as dax
+        
+        cfn_subnet_group = dax.CfnSubnetGroup(self, "MyCfnSubnetGroup",
+            subnet_ids=["subnetIds"],
+        
+            # the properties below are optional
+            description="description",
+            subnet_group_name="subnetGroupName"
+        )
     '''
 
     def __init__(
@@ -813,22 +923,22 @@ class CfnSubnetGroup(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        subnet_ids: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
+        subnet_ids: typing.Sequence[builtins.str],
     ) -> None:
         '''Create a new ``AWS::DAX::SubnetGroup``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
-        :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
         :param description: ``AWS::DAX::SubnetGroup.Description``.
         :param subnet_group_name: ``AWS::DAX::SubnetGroup.SubnetGroupName``.
+        :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
         '''
         props = CfnSubnetGroupProps(
-            subnet_ids=subnet_ids,
             description=description,
             subnet_group_name=subnet_group_name,
+            subnet_ids=subnet_ids,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -862,19 +972,6 @@ class CfnSubnetGroup(
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
         return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore[misc]
-    @jsii.member(jsii_name="subnetIds")
-    def subnet_ids(self) -> typing.List[builtins.str]:
-        '''``AWS::DAX::SubnetGroup.SubnetIds``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
-        '''
-        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))
-
-    @subnet_ids.setter
-    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
-        jsii.set(self, "subnetIds", value)
-
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
@@ -901,31 +998,58 @@ class CfnSubnetGroup(
     def subnet_group_name(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "subnetGroupName", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="subnetIds")
+    def subnet_ids(self) -> typing.List[builtins.str]:
+        '''``AWS::DAX::SubnetGroup.SubnetIds``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
+        '''
+        return typing.cast(typing.List[builtins.str], jsii.get(self, "subnetIds"))
+
+    @subnet_ids.setter
+    def subnet_ids(self, value: typing.List[builtins.str]) -> None:
+        jsii.set(self, "subnetIds", value)
+
 
 @jsii.data_type(
     jsii_type="@aws-cdk/aws-dax.CfnSubnetGroupProps",
     jsii_struct_bases=[],
     name_mapping={
-        "subnet_ids": "subnetIds",
         "description": "description",
         "subnet_group_name": "subnetGroupName",
+        "subnet_ids": "subnetIds",
     },
 )
 class CfnSubnetGroupProps:
     def __init__(
         self,
         *,
-        subnet_ids: typing.Sequence[builtins.str],
         description: typing.Optional[builtins.str] = None,
         subnet_group_name: typing.Optional[builtins.str] = None,
+        subnet_ids: typing.Sequence[builtins.str],
     ) -> None:
         '''Properties for defining a ``AWS::DAX::SubnetGroup``.
 
-        :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
         :param description: ``AWS::DAX::SubnetGroup.Description``.
         :param subnet_group_name: ``AWS::DAX::SubnetGroup.SubnetGroupName``.
+        :param subnet_ids: ``AWS::DAX::SubnetGroup.SubnetIds``.
 
         :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html
+
+        Example::
+
+            # The code below shows an example of how to instantiate this type.
+            # The values are placeholders you should change.
+            import aws_cdk.aws_dax as dax
+            
+            cfn_subnet_group_props = dax.CfnSubnetGroupProps(
+                subnet_ids=["subnetIds"],
+            
+                # the properties below are optional
+                description="description",
+                subnet_group_name="subnetGroupName"
+            )
         '''
         self._values: typing.Dict[str, typing.Any] = {
             "subnet_ids": subnet_ids,
@@ -935,16 +1059,6 @@ class CfnSubnetGroupProps:
         if subnet_group_name is not None:
             self._values["subnet_group_name"] = subnet_group_name
 
-    @builtins.property
-    def subnet_ids(self) -> typing.List[builtins.str]:
-        '''``AWS::DAX::SubnetGroup.SubnetIds``.
-
-        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
-        '''
-        result = self._values.get("subnet_ids")
-        assert result is not None, "Required property 'subnet_ids' is missing"
-        return typing.cast(typing.List[builtins.str], result)
-
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
         '''``AWS::DAX::SubnetGroup.Description``.
@@ -963,6 +1077,16 @@ class CfnSubnetGroupProps:
         result = self._values.get("subnet_group_name")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def subnet_ids(self) -> typing.List[builtins.str]:
+        '''``AWS::DAX::SubnetGroup.SubnetIds``.
+
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dax-subnetgroup.html#cfn-dax-subnetgroup-subnetids
+        '''
+        result = self._values.get("subnet_ids")
+        assert result is not None, "Required property 'subnet_ids' is missing"
+        return typing.cast(typing.List[builtins.str], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
